==> flink-1.17.2-src.tgz: flink-1.17.2/flink-runtime/src/test/java/org/apache/flink/runtime/rest/messages/taskmanager/TaskManagersInfoTest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.flink.runtime.rest.messages.taskmanager;

import org.apache.flink.runtime.rest.messages.RestResponseMarshallingTestBase;

import java.util.Arrays;

import static org.apache.flink.runtime.rest.messages.taskmanager.TaskManagerInfoTest.createRandomTaskManagerInfo;

/** Test for (un)marshalling of {@link TaskManagersInfo}. */
public class TaskManagersInfoTest extends RestResponseMarshallingTestBase<TaskManagersInfo> {

    @Override
    protected Class<TaskManagersInfo> getTestResponseClass() {
        return TaskManagersInfo.class;
    }

    @Override
    protected TaskManagersInfo getTestResponseInstance() throws Exception {
        final TaskManagerInfo taskManagerInfo1 = createRandomTaskManagerInfo();
        final TaskManagerInfo taskManagerInfo2 = createRandomTaskManagerInfo();

        return new TaskManagersInfo(Arrays.asList(taskManagerInfo1, taskManagerInfo2));
    }
}

==> flink-2.1.1-src.tgz: flink-2.1.1/flink-runtime/src/test/java/org/apache/flink/runtime/rest/messages/taskmanager/TaskManagersInfoTest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.flink.runtime.rest.messages.taskmanager;

import org.apache.flink.runtime.rest.messages.RestResponseMarshallingTestBase;
import org.apache.flink.testutils.junit.extensions.parameterized.NoOpTestExtension;

import org.junit.jupiter.api.extension.ExtendWith;

import java.util.Arrays;

import static org.apache.flink.runtime.rest.messages.taskmanager.TaskManagerInfoTest.createRandomTaskManagerInfo;

/** Test for (un)marshalling of {@link TaskManagersInfo}. */
@ExtendWith(NoOpTestExtension.class)
class TaskManagersInfoTest extends RestResponseMarshallingTestBase<TaskManagersInfo> {

    @Override
    protected Class<TaskManagersInfo> getTestResponseClass() {
        return TaskManagersInfo.class;
    }

    @Override
    protected TaskManagersInfo getTestResponseInstance() throws Exception {
        final TaskManagerInfo taskManagerInfo1 = createRandomTaskManagerInfo();
        final TaskManagerInfo taskManagerInfo2 = createRandomTaskManagerInfo();

        return new TaskManagersInfo(Arrays.asList(taskManagerInfo1, taskManagerInfo2));
    }
}
